Index: trunk/psLib/test/sysUtils/tst_psLogMsg00.c
===================================================================
--- trunk/psLib/test/sysUtils/tst_psLogMsg00.c	(revision 1096)
+++ trunk/psLib/test/sysUtils/tst_psLogMsg00.c	(revision 1138)
@@ -15,7 +15,7 @@
     va_list ap;
 
     // Test whether psVLogMsg() accept a va_list for output variables.
     va_start(ap, fmt);
-    psVLogMsg(name, level, fmt, ap);
+    psLogMsgV(name, level, fmt, ap);
     va_end(ap);
 }
@@ -44,5 +44,5 @@
 
 
     // Test whether psVLogMsg() accept a va_list for output variables.
     printPositiveTestHeader(stdout,
                             "psLogMsg functions",
@@ -15,7 +15,7 @@
     va_list ap;
 
-    // Test whether psVLogMsg() accept a va_list for output variables.
+    // Test whether psLogMsgV() accept a va_list for output variables.
     va_start(ap, fmt);
@@ -44,5 +44,5 @@
 
 
-    // Test whether psVLogMsg() accept a va_list for output variables.
+    // Test whether psLogMsgV() accept a va_list for output variables.
     printPositiveTestHeader(stdout,
                             "psLogMsg functions",
